@@ -381,6 +381,33 @@ for i in {1..30}; do
         # Enable pgvector extension
         sudo docker exec "$CONTAINER_NAME" psql -U ivs -d airun -c "CREATE EXTENSION IF NOT EXISTS vector;" 2>/dev/null || true
         show_success "pgvector 확장 활성화"
+
+        # Initialize database schema by running createTables function
+        show_info "데이터베이스 스키마 초기화 중..."
+        cd "$CURRENT_DIR"
+        if timeout 60 node -e "
+            process.env.DB_HOST = 'localhost';
+            process.env.DB_PORT = '5433';
+            process.env.DB_USER = 'ivs';
+            process.env.DB_PASSWORD = '1234';
+            process.env.DB_NAME = 'airun';
+
+            const { createTables } = require('./services/auth/schema.js');
+            (async () => {
+                try {
+                    await createTables();
+                    console.log('데이터베이스 스키마 초기화 완료');
+                    process.exit(0);
+                } catch (error) {
+                    console.error('데이터베이스 스키마 초기화 실패:', error.message);
+                    process.exit(1);
+                }
+            })();
+        " 2>/dev/null; then
+            show_success "데이터베이스 스키마 초기화 완료"
+        else
+            show_warning "데이터베이스 스키마 초기화 실패 (API 서버 시작 시 자동 실행됨)"
+        fi
         break
     fi
 
@@ -1041,6 +1068,23 @@ check_postgres() {
                 show_warning "pgvector 확장: 비활성화"
                 ((WARNINGS++))
             fi
+
+            # Check if essential tables exist (schema validation)
+            show_info "데이터베이스 스키마 검증..."
+            if PGPASSWORD=1234 psql -h localhost -p 5433 -U ivs -d airun -c "SELECT 1 FROM information_schema.tables WHERE table_name='users';" | grep -q "1"; then
+                show_success "기본 테이블: 생성됨"
+
+                # Check for embedding_status column specifically
+                if PGPASSWORD=1234 psql -h localhost -p 5433 -U ivs -d airun -c "SELECT column_name FROM information_schema.columns WHERE table_name='rag_documents' AND column_name='embedding_status';" | grep -q "embedding_status"; then
+                    show_success "RAG 스키마: embedding_status 컬럼 확인됨"
+                else
+                    show_warning "RAG 스키마: embedding_status 컬럼 없음"
+                    ((WARNINGS++))
+                fi
+            else
+                show_warning "데이터베이스 스키마: 초기화 안됨 (API 서버 시작 시 자동 생성됨)"
+                ((WARNINGS++))
+            fi
         else
             show_warning "PostgreSQL: 연결 실패 (재로그인 후 확인 필요)"
             show_info "Docker 그룹 권한이 현재 세션에 적용되지 않았을 수 있습니다"
